/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * $Id: DOMTreeErrorReporter.hpp 471735 2006-11-06 13:53:58Z amassari $
 */

#include <xercesc/util/XercesDefs.hpp>
#include <xercesc/sax/ErrorHandler.hpp>
#if defined(XERCES_NEW_IOSTREAMS)
#include <iostream>
#else
#include <iostream.h>
#endif


XERCES_CPP_NAMESPACE_USE

/**
 *\file DOMTreeErrorReporter.hpp
 *\date  Created on:2006-11-06
 *\author  Author: Apache Software Foundation (ASF), documented by Claudio Salvadori
 *\brief Development of the classes DOMTreeErrorReporter and StrX*/

/** 
*\class ErrorHandler
 *\brief Basic interface for SAX error handlers. From the Xerces package.*/

/** 
*\class DOMTreeErrorReporter
 *\brief This class registers as an ErrorHandler with the DOM parser and reports errors to the application*/


class DOMTreeErrorReporter : public ErrorHandler
{
public:
	// -----------------------------------------------------------------------
	//  Constructors and Destructor
	// -----------------------------------------------------------------------
    	
	/**\brief Constructor*/
	DOMTreeErrorReporter() : fSawErrors(false){}

	/**\brief Destructor*/
    	~DOMTreeErrorReporter(){}



	// -----------------------------------------------------------------------
	//  Implementation of the error handler interface
	// -----------------------------------------------------------------------
	
	/**\brief Warning handler
	* \param toCatch Instance of SAX Parser error handler class*/
	void warning(const SAXParseException& toCatch);

	/**\brief Error handler
	* \param toCatch Instance of SAX Parser error handler class*/	
	void error(const SAXParseException& toCatch);

	/**\brief Fatal error handler
	* \param toCatch Instance of SAX Parser error handler class*/
	void fatalError(const SAXParseException& toCatch);

	/**\brief Reset error*/
	void resetErrors();

	// -----------------------------------------------------------------------
	//  Getter methods
	// -----------------------------------------------------------------------
	/**\brief Getter methods
	* \return True if an error was found*/
	bool getSawErrors() const;
private:
	// -----------------------------------------------------------------------
	//  Private data members
	//
	//  fSawErrors
	//      This is set if we get any errors, and is queryable via a getter
	//      method. Its used by the main code to suppress output if there are
	//      errors.
	// -----------------------------------------------------------------------
	bool    fSawErrors;	/**<This is set true if we get any errors, and is queryable via a getter method.*/
};

inline bool DOMTreeErrorReporter::getSawErrors() const{
    	return fSawErrors;
}

// ---------------------------------------------------------------------------
//  This is a simple class that lets us do easy (though not terribly efficient)
//  trancoding of XMLCh data to local code page for display.
// ---------------------------------------------------------------------------
/** 
*\class StrX
 *\brief This is a simple class that lets us do easy (though not terribly efficient)
  	trancoding of XMLCh data to local code page for display.*/
class StrX
{
public :
	// -----------------------------------------------------------------------
	//  Constructors and Destructor
	// -----------------------------------------------------------------------
	/** \brief Constructor
	*\param toTranscode	Data to transocode*/
	StrX(const XMLCh* const toTranscode){
		// Call the private transcoding method
		fLocalForm = XMLString::transcode(toTranscode);
	}
	/** \brief Destructor*/
	~StrX(){
		XMLString::release(&fLocalForm);
	}


	// -----------------------------------------------------------------------
	//  Getter methods
	// -----------------------------------------------------------------------
	/**\brief Getter methods
	* \return Data transcoded*/
	const char* localForm() const{
		return fLocalForm;
	}

private :
	// -----------------------------------------------------------------------
	//  Private data members
	//
	//  fLocalForm
	//      This is the local code page form of the string.
	// -----------------------------------------------------------------------
	char*   fLocalForm;	/**<This is the local code page form of the string*/
};

inline XERCES_STD_QUALIFIER ostream& operator<<(XERCES_STD_QUALIFIER ostream& target, const StrX& toDump){
	target << toDump.localForm();
	return target;
}

